@@ -86,8 +86,6 @@ private Q_SLOTS:
     void setRecsrc(bool value);
     void setMuted(bool value);
     void volumeChange( int );
-    void sliderPressed();
-    void sliderReleased();
 
     void increaseVolume();
     void decreaseVolume();
@@ -143,7 +141,6 @@ private:
 
     QList<QAbstractSlider *> m_slidersPlayback;
     QList<QAbstractSlider *> m_slidersCapture;
-    bool m_sliderInWork;
     int m_waitForSoundSetComplete;
     QList<int> volumeValues;
 };
